Bu kütüphane, Levi-Civita sayıları, p-adik sayılar ve Sürreal sayılar üzerinde temel matematiksel işlemleri gerçekleştirmek için Python uygulamaları içerir.

## Kurulum

```bash
pip install surreallevi